require "srt_slicer/version"
require 'time'

module SrtSlicer
  class SrtSlicer
    def initialize(input_file, srt_file, start_time=nil, end_time=nil)
      @input_file = input_file.split(".")
      @srt_file = srt_file
      @start_time = start_time
      @end_time = end_time
      @output_files = []
    end

    def slice
      f = open(srt_file)
      num = 1
      f.each do |line|
        next unless line.index("-->")
        line = line.chomp.split(" ")
        delta = Time.parse(line[2]) - Time.parse(line[0])
        current = line[0].gsub(',', '.')
        output_file = "#{input_file[0]}-#{num.to_s.rjust(3, 0.to_s)}.#{input_file[1]}"

        next unless (start_time.nil? && end_time.nil?) ||
          (Time.parse(current) > Time.parse(start_time) &&
          Time.parse(line[2]) < Time.parse(end_time))

        system "ffmpeg -ss #{current} -t #{delta} -i #{input_file.join(".")} #{output_file}"
        @output_files << output_file
        num += 1
      end
      f.close
    end

    def clear
      @output_files.each { |f| system "rm #{f}" }
    end

    private
    def input_file
      @input_file
    end

    def srt_file
      @srt_file
    end

    def start_time
      @start_time
    end

    def end_time
      @end_time
    end
  end
end
